pub fn simple_math_op_sys(stack: &mut Stack, operator: &MathOperator)Expand description
A simple operator system that decides how each of the variants of MathOperator
trigger push and pulls on the Stack inside a Machine.
pub fn simple_math_op_sys(stack: &mut Stack, operator: &MathOperator)A simple operator system that decides how each of the variants of MathOperator
trigger push and pulls on the Stack inside a Machine.